pub struct FleetPlugin {
pub config: FleetConfig,
}Expand description
The Fleet plugin that can be added to a Bevy app
Fields
config: FleetConfigTrait Implementations
Sourceimpl Clone for FleetPlugin
impl Clone for FleetPlugin
Sourcefn clone(&self) -> FleetPlugin
fn clone(&self) -> FleetPlugin
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for FleetPlugin
impl Default for FleetPlugin
Sourcefn default() -> FleetPlugin
fn default() -> FleetPlugin
Returns the “default value” for a type. Read more
Sourceimpl Plugin for FleetPlugin
Registers the Fleet plugin with Bevy
impl Plugin for FleetPlugin
Registers the Fleet plugin with Bevy
Sourcefn ready(&self, _app: &App) -> bool
fn ready(&self, _app: &App) -> bool
Has the plugin finished its setup? This can be useful for plugins that need something
asynchronous to happen before they can finish their setup, like the initialization of a renderer.
Once the plugin is ready,
finish should be called.Sourcefn finish(&self, _app: &mut App)
fn finish(&self, _app: &mut App)
Finish adding this plugin to the
App, once all plugins registered are ready. This can
be useful for plugins that depends on another plugin asynchronous setup, like the renderer.Sourcefn cleanup(&self, _app: &mut App)
fn cleanup(&self, _app: &mut App)
Runs after all plugins are built and finished, but before the app schedule is executed.
This can be useful if you have some resource that other plugins need during their build step,
but after build you want to remove it and send it to another thread.